@@ -17,11 +17,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#define _GNU_SOURCE
-
 #include "mbexp.h"
 
-void /* Not Used  */
+void 
 mb_init(void)
 {
   /* XXXX init gtype system here ? */
@@ -171,13 +169,6 @@ mb_col_unref(MBColor *col)
   col->ref_cnt--;
   if (col->ref_cnt == 0)
     {
-#if defined (USE_XFT) || defined (USE_PANGO)
-      MBPixbuf *pb = col->pb;
-      XftColorFree (pb->dpy,
-                    DefaultVisual(pb->dpy, pb->scr),
-                    DefaultColormap(pb->dpy, pb->scr),
-                    &col->xftcol);
-#endif
       free(col);
       col = NULL;
     }
@@ -406,10 +397,6 @@ mb_font_new(Display *dpy,
 #endif
   
   font = malloc(sizeof(MBFont));
-
-  if (font == NULL)
-    return NULL;
-
   memset(font, 0, sizeof(MBFont));
 
   if (family != NULL)
@@ -429,12 +416,9 @@ mb_font_new(Display *dpy,
    font->pgo_fontmap = pango_xft_get_font_map (font->dpy, DefaultScreen(dpy));
    font->fontdes     = pango_font_description_new ();
 
-   /* If Pango is mis-setup the above will fail */
-   if (font->pgo_context == NULL || font->pgo_fontmap == NULL || font->fontdes == NULL)
-     {
-       free(font);
-       return NULL;
-     }
+   /* -- Needed ?
+   pango_context_set_language (w->pgo, pango_language_from_string ("ar_AE"));
+   */
 
 #elif defined (USE_XFT)
 
@@ -588,11 +572,8 @@ MBFont*
 mb_font_new_from_string(Display *dpy, char *spec) 
 {
   MBFont *font = mb_font_new(dpy, NULL);
-
-  if (font)
-    return mb_font_set_from_string(font, spec); 
-
-  return NULL;
+  mb_font_set_from_string(font, spec); 
+  return font;
 }
 
 MBFont*
@@ -618,27 +599,17 @@ mb_font_unref(MBFont* font)
 
   if (!font->ref_cnt)
     {
-      if (font->col)
-	mb_col_unref (font->col);
-#ifdef USE_PANGO
-      if (font->fontdes)
-	pango_font_description_free (font->fontdes);
-      if (font->pgo_context)
-	g_object_unref (font->pgo_context);
-      /* The Pango fontmap is owned by Pango apparently */
+      if (font->family) free(font->family);
 
-#elif defined (USE_XFT)
-      ;
-#else
-      if (font->gc) XFreeGC(font->dpy, font->gc);
-#endif
+#if defined (USE_PANGO)
+      /* FIXME To free 
 
-      if (font->family) 
-	free(font->family);
+      font->pgo_context
+      font->pgo_fontmap
+      font->fontdes    
 
-      _mb_font_free(font);
-
-      free(font);
+      */
+#endif      
     }
 }
 
@@ -904,7 +875,7 @@ _clip_some_text (MBFont         *font,
 		 int             encoding,
 		 int             opts)
 {
-  int len = strlen((char*)txt);
+  int len = strlen(txt);
 
   /* we cant clip single char string */
   if (len < 2) return 0;
@@ -916,7 +887,8 @@ _clip_some_text (MBFont         *font,
       unsigned char *str = malloc(len+5);
       memset(str, 0, len+5);
 
-      strcpy((char*)str, (char*)txt);
+      /* len += 2; */
+      strcpy(str, txt);
 
       do {
 	  /* go back a glyth */
@@ -1075,12 +1047,12 @@ mb_font_render_simple (MBFont          *font,
   if (!_mb_font_is_font_object_fresh (font))
     _mb_font_load(font);
 
-  orig_len = len = strlen((char*)text);
+  orig_len = len = strlen(text);
 
   str = malloc(len+3);
   memset(str, 0, len+3);
 
-  strcpy((char*)str, (char*)text);
+  strcpy(str, text);
 
   render_w = mb_font_get_txt_width(font, str, len, encoding);
 
@@ -1094,18 +1066,13 @@ mb_font_render_simple (MBFont          *font,
        */
 
 
+
       len = _clip_some_text (font, width, str, encoding, opts);
 
       if (!len) { free(str); return 0; }
       
       if ((opts & MB_FONT_RENDER_OPTS_CLIP_TRAIL) && len > 3)
-	{
-	  /* Avoid having a space before the elipsis */
-	  while (len-1 >= 0 && str[len-1] == ' ')
-	    len--;
-
 	  want_dots = True;
-	}
     }
   else
     {
@@ -1161,12 +1128,12 @@ mb_font_render_simple_get_width (MBFont          *font,
   if (!_mb_font_is_font_object_fresh (font))
     _mb_font_load(font);
 
-  orig_len = len = strlen((char*)text);
+  orig_len = len = strlen(text);
 
   str = malloc(len+3);
   memset(str, 0, len+3);
 
-  strcpy((char*)str, (char*)text);
+  strcpy(str, text);
 
   render_w = mb_font_get_txt_width(font, str, len, encoding);
 
@@ -1271,7 +1238,7 @@ mb_layout_set_text(MBLayout       *layout,
 {
   if (layout->txt) free(layout->txt);
 
-  layout->txt = (unsigned char*)strdup((char*)text);
+  layout->txt = strdup(text);
   layout->txt_encoding = encoding;
 }
 
@@ -1318,7 +1285,7 @@ _mb_layout_render_magic (MBLayout        *layout,
 			 MBFontRenderOpts opts,
 			 Bool             do_render)
 {
-  unsigned char *orig_p, *p = (unsigned char*)strdup((char*)layout->txt);
+  unsigned char *orig_p, *p = strdup(layout->txt);
   unsigned char *q = p;
   unsigned char *backtrack = NULL;
   int            v_offset  = 0;
@@ -1340,7 +1307,7 @@ _mb_layout_render_magic (MBLayout        *layout,
 	  
 	  /* XXX q should be current_line_start */
 
-	  cur_width = mb_font_get_txt_width(layout->font, q, strlen((char*)q), 
+	  cur_width = mb_font_get_txt_width(layout->font, q, strlen(q), 
 					    layout->txt_encoding) ;
 	  
 	  if (cur_width > layout->width )
@@ -1419,7 +1386,7 @@ mb_layout_render (MBLayout        *layout,
 
   if (layout->_have_autocalc_size) /* Easy case */
     {
-      char *str = strdup((char*)layout->txt), *start = NULL, *orig = NULL;
+      unsigned char *str = strdup(layout->txt), *start = NULL, *orig = NULL;
 
       orig = str;
 
@@ -1440,7 +1407,7 @@ mb_layout_render (MBLayout        *layout,
 		                 x,
 		                 y,
 				 layout->width,
-				 (unsigned char*)start,
+				 start,
 		                 layout->txt_encoding,
 		                 0 );
 	  
